
/****************************************************************************
 * NCSA HDF                                                                 *
 * Scientific Data Technologies                                             *
 * National Center for Supercomputing Applications                          *
 * University of Illinois at Urbana-Champaign                               *
 * 605 E. Springfield, Champaign IL 61820                                   *
 *                                                                          *
 * For conditions of distribution and use, see the accompanying             *
 * hdf/COPYING f.                                                           *
 *                                                                          *
 ****************************************************************************/

#include <stdlib.h>

#include "H5HL.h"

#define FILE_NAME "lite_dset_test.h5"

#define DSET0_NAME "2D int array"
#define DSET1_NAME "dataset char"
#define DSET2_NAME "dataset short"
#define DSET3_NAME "dataset int"
#define DSET4_NAME "dataset long"
#define DSET5_NAME "dataset float"
#define DSET6_NAME "dataset double"

#define ATTR1_NAME "Attribute string"
#define ATTR2_NAME "Attribute int"
#define ATTR3_NAME "Attribute float"

#define DIM 6


int main( void )
{
 int     rank     = 2;
 hsize_t dims[2]  = {2,3};
 hid_t   file_id;
 hid_t   dataset_id;
 char    data_char_in[DIM]    = {1,2,3,4,5,6};
 char    data_char_out[DIM];
 short   data_short_in[DIM]   = {1,2,3,4,5,6};
 short   data_short_out[DIM];
 int     data_int_in[DIM]     = {1,2,3,4,5,6};   
 int     data_int_out[DIM];
 long    data_long_in[DIM]    = {1,2,3,4,5,6};
 long    data_long_out[DIM];
 float   data_float_in[DIM]   = {1,2,3,4,5,6};
 float   data_float_out[DIM];
 double  data_double_in[DIM]  = {1,2,3,4,5,6};
 double  data_double_out[DIM];
 int     i;

 
 /* Create a new file using default properties. */
 file_id = H5Fcreate( FILE_NAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT );

/*-------------------------------------------------------------------------
 * H5LTmake_dataset test
 *-------------------------------------------------------------------------
 */

 TESTING("H5LTmake_dataset");

 /* Make dataset */
 if ( H5LTmake_dataset( file_id, DSET0_NAME, rank, dims, H5T_NATIVE_INT, data_int_in ) < 0 )
  goto out;

 /* Read dataset using the basic HDF5 API */

 if ( ( dataset_id = H5Dopen ( file_id, DSET0_NAME) ) < 0 ) 
  goto out;

 if ( H5Dread ( dataset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, data_int_out ) < 0 ) 
  goto out;

 if ( H5Dclose( dataset_id ) < 0 ) 
  goto out;

 for (i = 0; i < DIM; i++)
 {
  if ( data_int_in[i] != data_int_out[i] ) {
    goto out;
  }
 }

 PASSED();

/*-------------------------------------------------------------------------
 * read using the LT function H5LTread_dataset 
 *-------------------------------------------------------------------------
 */

 TESTING("H5LTread_dataset");

 if ( H5LTread_dataset( file_id, DSET0_NAME, H5T_NATIVE_INT, data_int_out ) < 0 )
  goto out;

 for (i = 0; i < DIM; i++)
 {
  if ( data_int_in[i] != data_int_out[i] ) {
    goto out;
  }
 }

 PASSED();
 
/*-------------------------------------------------------------------------
 * test the H5LTmake_dataset_ functions
 *-------------------------------------------------------------------------
 */


/*-------------------------------------------------------------------------
 * H5LTmake_dataset_char 
 *-------------------------------------------------------------------------
 */

 TESTING("H5LTmake_dataset_char");

 /* Make dataset char */
 if ( H5LTmake_dataset_char( file_id, DSET1_NAME, rank, dims, data_char_in ) < 0 )
  goto out;

 /* Read dataset */
 if ( H5LTread_dataset( file_id, DSET1_NAME, H5T_NATIVE_CHAR, data_char_out ) < 0 )
  goto out;

 for (i = 0; i < DIM; i++)
 {
  if ( data_char_in[i] != data_char_out[i] ) {
    goto out;
  }
 }

 /* Read dataset */
 if ( H5LTread_dataset_char( file_id, DSET1_NAME, data_char_out ) < 0 )
  goto out;

 for (i = 0; i < DIM; i++)
 {
  if ( data_char_in[i] != data_char_out[i] ) {
    goto out;
  }
 }

 PASSED();


/*-------------------------------------------------------------------------
 * H5LTmake_dataset_short 
 *-------------------------------------------------------------------------
 */

 TESTING("H5LTmake_dataset_short");

 /* Make dataset short */
 if ( H5LTmake_dataset_short( file_id, DSET2_NAME, rank, dims, data_short_in ) < 0 )
  goto out;

 /* Read dataset */
 if ( H5LTread_dataset( file_id, DSET2_NAME, H5T_NATIVE_SHORT, data_short_out ) < 0 )
  goto out;

 for (i = 0; i < DIM; i++)
 {
  if ( data_short_in[i] != data_short_out[i] ) {
    goto out;
  }
 }

 /* Read dataset */
 if ( H5LTread_dataset_short( file_id, DSET2_NAME, data_short_out ) < 0 )
  goto out;

 for (i = 0; i < DIM; i++)
 {
  if ( data_short_in[i] != data_short_out[i] ) {
    goto out;
  }
 }

 PASSED();

/*-------------------------------------------------------------------------
 * H5LTmake_dataset_int 
 *-------------------------------------------------------------------------
 */

 TESTING("H5LTmake_dataset_int");

 /* Make dataset int */
 if ( H5LTmake_dataset_int( file_id, DSET3_NAME, rank, dims, data_int_in ) < 0 )
  goto out;

 /* Read dataset */
 if ( H5LTread_dataset( file_id, DSET3_NAME, H5T_NATIVE_INT, data_int_out ) < 0 )
  goto out;
 
 for (i = 0; i < DIM; i++)
 {
  if ( data_int_in[i] != data_int_out[i] ) {
    goto out;
  }
 }
 
 /* Read dataset */
 if ( H5LTread_dataset_int( file_id, DSET3_NAME, data_int_out ) < 0 )
  goto out;

 for (i = 0; i < DIM; i++)
 {
  if ( data_int_in[i] != data_int_out[i] ) {
    goto out;
  }
 }

 PASSED();


/*-------------------------------------------------------------------------
 * H5LTmake_dataset_long 
 *-------------------------------------------------------------------------
 */

 TESTING("H5LTmake_dataset_long");

 /* Make dataset long */
 if ( H5LTmake_dataset_long( file_id, DSET4_NAME, rank, dims, data_long_in ) < 0 )
  goto out;

 /* Read dataset */
 if ( H5LTread_dataset( file_id, DSET4_NAME, H5T_NATIVE_LONG, data_long_out ) < 0 )
  goto out;

 for (i = 0; i < DIM; i++)
 {
  if ( data_long_in[i] != data_long_out[i] ) {
    goto out;
  }
 }

  /* Read dataset */
 if ( H5LTread_dataset_long( file_id, DSET4_NAME, data_long_out ) < 0 )
  goto out;

 for (i = 0; i < DIM; i++)
 {
  if ( data_long_in[i] != data_long_out[i] ) {
    goto out;
  }
 }

 PASSED();


/*-------------------------------------------------------------------------
 * H5LTmake_dataset_float 
 *-------------------------------------------------------------------------
 */

 TESTING("H5LTmake_dataset_float");

 /* Make dataset float */
 if ( H5LTmake_dataset_float( file_id, DSET5_NAME, rank, dims, data_float_in ) < 0 )
  goto out;

 /* Read dataset */
 if ( H5LTread_dataset( file_id, DSET5_NAME, H5T_NATIVE_FLOAT, data_float_out ) < 0 )
  goto out;

 for (i = 0; i < DIM; i++)
 {
  if ( data_float_in[i] != data_float_out[i] ) {
    goto out;
  }
 }

  /* Read dataset */
 if ( H5LTread_dataset_float( file_id, DSET5_NAME, data_float_out ) < 0 )
  goto out;

 for (i = 0; i < DIM; i++)
 {
  if ( data_float_in[i] != data_float_out[i] ) {
    goto out;
  }
 }

 PASSED();


/*-------------------------------------------------------------------------
 * H5LTmake_dataset_double 
 *-------------------------------------------------------------------------
 */

 TESTING("H5LTmake_dataset_double");

 /* Make dataset double */
 if ( H5LTmake_dataset_double( file_id, DSET6_NAME, rank, dims, data_double_in ) < 0 )
  goto out;

 /* Read dataset */
 if ( H5LTread_dataset( file_id, DSET6_NAME, H5T_NATIVE_DOUBLE, data_double_out ) < 0 )
  goto out;
 
 for (i = 0; i < DIM; i++)
 {
  if ( data_double_in[i] != data_double_out[i] ) {
    goto out;
  }
 }

  /* Read dataset */
 if ( H5LTread_dataset_double( file_id, DSET6_NAME, data_double_out ) < 0 )
  goto out;

 for (i = 0; i < DIM; i++)
 {
  if ( data_double_in[i] != data_double_out[i] ) {
    goto out;
  }
 }

 


/*-------------------------------------------------------------------------
 * end tests
 *-------------------------------------------------------------------------
 */
 
 /* Close the file. */
 H5Fclose( file_id );

 PASSED();


 return 0;

out:
 /* Close the file. */
 H5_FAILED();
 return 1;

 

}
